Python Driver for Oracle NoSQL Database
===========================================

A Python driver for Oracle NoSQL Database.  This driver requires at least
version 4.2.x of Oracle NoSQL Database and makes use of a (bundled) Java
proxy server to communicate with the database.  Communication with the
proxy is done using a Thrift-based protocol.

This driver supports Python 2.6 and 2.7.


Installation
------------
Installation using pip is recommended (this requires installation of pip on
your system, and  may require administrator access)::

    $ pip install nosqldb

The source code may be downloaded from this site and used for build and
test.  The source download includes example programs and unit tests.  It is
recommended that developers new to this driver read the examples and
documentation.

Documentation
-------------
The documentation for this driver can be found on the `Oracle NoSQL Documentation Page <http://docs.oracle.com/cd/NOSQL/html/index.html>`_.
This is the entire documentation set for Oracle NoSQL Database.  Look for the
Python driver section.

Support
-------------
If there are questions and comments on this release please post them on the `Oracle NoSQL Page of the Oracle Technology Network <https://community.oracle.com/community/database/high_availability/nosql_database>`_.
